@@ -1,4 +1,5 @@
-// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -142,8 +143,6 @@ void service::pointer::operator=(keynode *p)
 service::callback::callback(int rl) :
 OrderedObject()
 {
-    if(rl == 2)
-        abort();
     crit(rl < (int)RUNLEVELS, "service runlevel invalid");
     if(rl < 0) {
         rl += RUNLEVELS;
